import shlex
from subprocess import Popen, PIPE
import codecs


# return stdout, stderr
# raise exception if failed to execute
def run(cmd, timeout_sec=None, execute_dir=None, env=None):
    proc = Popen(shlex.split(cmd), stdout=PIPE, stderr=PIPE, cwd=execute_dir, env=env)
    stdout_b, stderr_b = proc.communicate(timeout=timeout_sec)
    return codecs.decode(stdout_b).strip(), codecs.decode(stderr_b).strip()
